@@ -10,7 +10,7 @@
  ***************************************************************************/
 
 #include "taskEditorDialog.h"
-
+#include "kwidgetsaddons_version.h"
 #include <QLabel>
 
 #include <QLayout>
@@ -552,12 +552,17 @@ QGroupBox* TaskEditorDialog::createHoursGroup(QWidget* main) {
 
 void TaskEditorDialog::setupTitleWidget(const QString& comment, KTitleWidget::MessageType messageType) {
 	titleWidget->setComment(comment, messageType);
-
+#if KWIDGETSADDONS_VERSION < QT_VERSION_CHECK(5, 63, 0)
 	if (messageType == KTitleWidget::ErrorMessage)
 		titleWidget->setPixmap(QIcon::fromTheme(QStringLiteral("dialog-error")), KTitleWidget::ImageRight);
 	else
 		titleWidget->setPixmap(QIcon::fromTheme(QStringLiteral("system-run")), KTitleWidget::ImageRight);
-
+#else
+    if (messageType == KTitleWidget::ErrorMessage)
+        titleWidget->setIcon(QIcon::fromTheme(QStringLiteral("dialog-error")), KTitleWidget::ImageRight);
+    else
+        titleWidget->setIcon(QIcon::fromTheme(QStringLiteral("system-run")), KTitleWidget::ImageRight);
+#endif
 }
 
 void TaskEditorDialog::slotEnabledChanged() {
@@ -1065,7 +1070,7 @@ NumberPushButton::NumberPushButton(QWidget * parent) :
 NumberPushButton::NumberPushButton(bool digitMode, QWidget * parent) :
 	QPushButton(parent), isDirty(false) {
 	if (digitMode) {
-		setFixedWidth(12 + fontMetrics().width(QStringLiteral( "44" )));
+	        setFixedWidth(12 + fontMetrics().boundingRect(QStringLiteral( "44" )).width());
 		KAcceleratorManager::setNoAccel(this);
 	}
 	updatePalette();
